@@ -8,7 +8,7 @@
  * Rancier <mephis5@softhome.net>. The Twofish code was taken from Doug 
  * Whiting's C implementation from www.counterpane.com.
  * 
- * $Id: ncrypt.c,v 1.4 2003/05/03 07:01:31 s-nomad Exp $
+ * $Id: ncrypt.c,v 1.6 2003/08/08 20:28:38 s-nomad Exp $
  */
 
 #include <stdio.h>
@@ -213,11 +213,21 @@ int main(int argc, char** argv)
     if (ARGS.wipe_given_gutmann) wipe_mode = WIPE_GUTMANN;
     if (ARGS.wipe_given_military) wipe_mode = WIPE_MILITARY;
     if ((ARGS.wipe_given_gutmann) && (ARGS.wipe_given_military)) wipe_mode = WIPE_BOTH;
-    if (ARGS.wipe_only) return wipe(wipe_mode);
+    if (ARGS.wipe_only)
+    {
+	    if(!wipe_mode) wipe_mode = WIPE_MILITARY;
+	    return wipe(wipe_mode);
+    }
 
-    if (ARGS.encrypt_given) rc = encrypt(ifp,ofp);
-    
-    if (wipe_mode && (rc == 0)) rc = wipe(wipe_mode);
+    if (ARGS.encrypt_given) 
+    {
+	    rc = encrypt(ifp,ofp);
+	    if (ARGS.wipe_on_encrypt && (rc == 0))
+	    {
+		    if(!wipe_mode) wipe_mode = WIPE_MILITARY;
+		    rc = wipe(wipe_mode);
+	    }
+    }
     if (ARGS.decrypt_given) rc = decrypt(ifp,ofp);
 
     fclose(ifp);
